pub struct DisjunctiveMatchStatement {
pub event_filters: Option<Vec<EventFilter>>,
pub kind: Option<String>,
}Expand description
Represents a Disjunctive Match Statement resource, which is a conjunction (and) of disjunctive (or) boolean statements.
This type is not used in any activity, and only used as part of another schema.
Fields
event_filters: Option<Vec<EventFilter>>The event filters contained within this disjunctive match statement.
kind: Option<String>The kind of resource this is, in this case dfareporting#disjunctiveMatchStatement.