pub struct ReportPathCriteria {
pub activity_filters: Option<Vec<DimensionValue>>,
pub custom_channel_grouping: Option<ChannelGrouping>,
pub date_range: Option<DateRange>,
pub dimensions: Option<Vec<SortedDimension>>,
pub floodlight_config_id: Option<DimensionValue>,
pub metric_names: Option<Vec<String>>,
pub path_filters: Option<Vec<PathFilter>>,
}Expand description
The report criteria for a report of type “PATH”.
This type is not used in any activity, and only used as part of another schema.
Fields
activity_filters: Option<Vec<DimensionValue>>The list of ‘dfa:activity’ values to filter on.
custom_channel_grouping: Option<ChannelGrouping>Channel Grouping.
date_range: Option<DateRange>The date range this report should be run for.
dimensions: Option<Vec<SortedDimension>>The list of dimensions the report should include.
floodlight_config_id: Option<DimensionValue>The floodlight ID for which to show data in this report. All advertisers associated with that ID will automatically be added. The dimension of the value needs to be ‘dfa:floodlightConfigId’.
metric_names: Option<Vec<String>>The list of names of metrics the report should include.
path_filters: Option<Vec<PathFilter>>Path Filters.